@@ -30,7 +30,7 @@
 
 #include <kcompletionbox.h>
 #include <kcursor.h>
-#include <QDebug>
+#include "khtml_debug.h"
 #include <kfind.h>
 #include <kfinddialog.h>
 #include <klocalizedstring.h>
@@ -58,10 +58,8 @@
 #include <QStyle>
 #include <QStyleOptionButton>
 #include <QLabel>
-#include <QStyleOptionFrameV3>
+#include <QStyleOptionFrame>
 #include <QStandardItemModel>
-#include <QListWidget>
-#include <QProxyStyle>
 
 #include <misc/helper.h>
 #include <xml/dom2_eventsimpl.h>
@@ -93,7 +91,7 @@ struct KHTMLProxyStyle : public QProxyStyle {
         clearButtonOverlay = 0;
     }
 
-    QRect subElementRect(SubElement element, const QStyleOption *option, const QWidget *widget) const Q_DECL_OVERRIDE
+    QRect subElementRect(SubElement element, const QStyleOption *option, const QWidget *widget) const override
     {
         QRect r = QProxyStyle::subElementRect(element, option, widget);
         switch (element) {
@@ -107,7 +105,7 @@ struct KHTMLProxyStyle : public QProxyStyle {
         return r;
     }
 
-    void drawControl(ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const Q_DECL_OVERRIDE
+    void drawControl(ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const override
     {
         if (element == QStyle::CE_ComboBoxLabel) {
             const QStyleOptionComboBox *o = qstyleoption_cast<const QStyleOptionComboBox *>(option);
@@ -129,7 +127,7 @@ struct KHTMLProxyStyle : public QProxyStyle {
         QProxyStyle::drawControl(element, option, painter, widget);
     }
 
-    void drawComplexControl(ComplexControl cc, const QStyleOptionComplex *opt, QPainter *painter, const QWidget *widget) const Q_DECL_OVERRIDE
+    void drawComplexControl(ComplexControl cc, const QStyleOptionComplex *opt, QPainter *painter, const QWidget *widget) const override
     {
         if ((cc == QStyle::CC_ComboBox) && noBorder) {
             if (const QStyleOptionComboBox *cbOpt = qstyleoption_cast<const QStyleOptionComboBox *>(opt)) {
@@ -177,7 +175,7 @@ struct KHTMLProxyStyle : public QProxyStyle {
         QProxyStyle::drawComplexControl(cc, opt, painter, widget);
     }
 
-    QRect subControlRect(ComplexControl cc, const QStyleOptionComplex *opt, SubControl sc, const QWidget *widget) const Q_DECL_OVERRIDE
+    QRect subControlRect(ComplexControl cc, const QStyleOptionComplex *opt, SubControl sc, const QWidget *widget) const override
     {
         // Make sure we give combo popup's enough room to display contents;
         // Qt doesn't do this by default
@@ -223,7 +221,7 @@ struct KHTMLProxyStyle : public QProxyStyle {
 RenderFormElement::RenderFormElement(HTMLGenericFormElementImpl *element)
     : RenderWidget(element)
 //     , m_state(0)
-    , m_proxyStyle(0)
+    , m_proxyStyle(nullptr)
     , m_exposeInternalPadding(false)
     , m_isOxygenStyle(false)
 {
@@ -303,7 +301,7 @@ void RenderFormElement::setQWidget(QWidget *w)
 {
     // Avoid dangling proxy pointer when we switch widgets.
     // the widget will cleanup the proxy, as it is its kid.
-    m_proxyStyle = 0;
+    m_proxyStyle = nullptr;
 
     // sets the Qt Object Name for the purposes
     // of setPadding() -- this is because QStyleSheet
@@ -375,7 +373,7 @@ int RenderFormElement::calcContentWidth(int w) const
 {
     if (!shouldDisableNativeBorders()) {
         if (style()->boxSizing() == CONTENT_BOX) {
-            int nativeBorderWidth = m_widget->style()->pixelMetric(QStyle::PM_DefaultFrameWidth, 0, m_widget);
+            int nativeBorderWidth = m_widget->style()->pixelMetric(QStyle::PM_DefaultFrameWidth, nullptr, m_widget);
             return RenderBox::calcContentWidth(w) + 2 * nativeBorderWidth;
         }
     }
@@ -387,7 +385,7 @@ int RenderFormElement::calcContentHeight(int h) const
 {
     if (!shouldDisableNativeBorders()) {
         if (style()->boxSizing() == CONTENT_BOX) {
-            int nativeBorderWidth = m_widget->style()->pixelMetric(QStyle::PM_DefaultFrameWidth, 0, m_widget);
+            int nativeBorderWidth = m_widget->style()->pixelMetric(QStyle::PM_DefaultFrameWidth, nullptr, m_widget);
             return RenderBox::calcContentHeight(h) + 2 * nativeBorderWidth;
         }
     }
@@ -784,13 +782,13 @@ namespace khtml
 class CompletionWidget: public KCompletionBox
 {
 public:
-    CompletionWidget(QWidget *parent = 0) : KCompletionBox(parent) {}
-    QPoint globalPositionHint() const Q_DECL_OVERRIDE
+    CompletionWidget(QWidget *parent = nullptr) : KCompletionBox(parent) {}
+    QPoint globalPositionHint() const override
     {
         QWidget *pw = parentWidget();
         KHTMLWidget *kwp = dynamic_cast<KHTMLWidget *>(pw);
         if (!kwp) {
-            qDebug() << "CompletionWidget has no KHTMLWidget parent" << endl;
+            qCDebug(KHTML_LOG) << "CompletionWidget has no KHTMLWidget parent";
             return KCompletionBox::globalPositionHint();
         }
         QPoint dest;
@@ -832,7 +830,7 @@ void LineEditWidget::slotCheckSpelling()
     if (text().isEmpty()) {
         return;
     }
-    Sonnet::Dialog *spellDialog = new Sonnet::Dialog(new Sonnet::BackgroundChecker(this), 0);
+    Sonnet::Dialog *spellDialog = new Sonnet::Dialog(new Sonnet::BackgroundChecker(this), nullptr);
     connect(spellDialog, SIGNAL(replace(QString,int,QString)), this, SLOT(spellCheckerCorrected(QString,int,QString)));
     connect(spellDialog, SIGNAL(misspelling(QString,int)), this, SLOT(spellCheckerMisspelling(QString,int)));
     connect(spellDialog, SIGNAL(done(QString)), this, SLOT(slotSpellCheckDone(QString)));
@@ -921,7 +919,7 @@ bool WebShortcutCreator::createWebShortcut(QString query)
                             break;
                         }
                         if (s == t) {
-                            KMessageBox::sorry(0, i18n("%1 is already assigned to %2", s, provider->name()), i18n("Error"));
+                            KMessageBox::sorry(nullptr, i18n("%1 is already assigned to %2", s, provider->name()), i18n("Error"));
                             isOk = false;
                         }
                     }
@@ -955,7 +953,7 @@ void WebShortcutCreator::createFile(QString query, QString name, QString keys)
     f.desktopGroup().writeEntry("Name", name);
     f.desktopGroup().writeEntry("Query", query);
     f.sync();
-    KBuildSycocaProgressDialog::rebuildKSycoca(0);
+    KBuildSycocaProgressDialog::rebuildKSycoca(nullptr);
 }
 
 bool WebShortcutCreator::askData(QString &name, QString &keys)
@@ -1167,10 +1165,10 @@ void RenderLineEdit::setStyle(RenderStyle *_style)
 
     bool showClearButton = (!shouldDisableNativeBorders() && !_style->hasBackgroundImage());
 
-    if (!showClearButton && widget()->isClearButtonShown()) {
-        widget()->setClearButtonShown(false);
-    } else if (showClearButton && !widget()->isClearButtonShown()) {
-        widget()->setClearButtonShown(true);
+    if (!showClearButton && widget()->isClearButtonEnabled()) {
+        widget()->setClearButtonEnabled(false);
+    } else if (showClearButton && !widget()->isClearButtonEnabled()) {
+        widget()->setClearButtonEnabled(true);
         QObjectList children = widget()->children();
         foreach (QObject *object, children) {
             QWidget *w = qobject_cast<QWidget *>(object);
@@ -1403,12 +1401,12 @@ RenderObject *RenderFieldset::findLegend() const
             return legend;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 void RenderFieldset::paintBoxDecorations(PaintInfo &pI, int _tx, int _ty)
 {
-    //qDebug() << renderName() << "::paintDecorations()";
+    //qCDebug(KHTML_LOG) << renderName() << "::paintDecorations()";
 
     RenderObject *legend = findLegend();
     if (!legend) {
@@ -1901,7 +1899,7 @@ void RenderSelect::updateFromElement()
                 QString text;
 
                 ElementImpl *parentOptGroup = optElem->parentNode()->id() == ID_OPTGROUP ?
-                                              static_cast<ElementImpl *>(optElem->parentNode()) : 0;
+                                              static_cast<ElementImpl *>(optElem->parentNode()) : nullptr;
 
                 if (parentOptGroup) {
                     text = QLatin1String("    ") + domText.string();
@@ -2025,7 +2023,7 @@ void RenderSelect::layout()
             size = qMin(w->count(), 10);
         }
 
-        QStyleOptionFrameV3 opt;
+        QStyleOptionFrame opt;
         opt.initFrom(w);
         opt.lineWidth = w->lineWidth();
         opt.midLineWidth = w->midLineWidth();
@@ -2055,7 +2053,7 @@ void RenderSelect::layout()
         int h = s.height();
 
         if (shouldDisableNativeBorders()) {
-            const int dfw = 2 * m_widget->style()->pixelMetric(QStyle::PM_DefaultFrameWidth, 0, m_widget);
+            const int dfw = 2 * m_widget->style()->pixelMetric(QStyle::PM_DefaultFrameWidth, nullptr, m_widget);
             w -= dfw;
             h -= dfw;
         }
@@ -2344,7 +2342,7 @@ void RenderTextArea::calcMinMaxWidth()
     int lbm = qMax(0, w->style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
     int ltm = qMax(0, w->style()->pixelMetric(QStyle::PM_LayoutTopMargin));
 
-    QStyleOptionFrameV3 opt;
+    QStyleOptionFrame opt;
     opt.initFrom(w);
     opt.lineWidth = w->lineWidth();
     opt.midLineWidth = w->midLineWidth();
@@ -2463,7 +2461,7 @@ void RenderTextArea::updateFromElement()
 {
     TextAreaWidget *w = static_cast<TextAreaWidget *>(m_widget);
     w->setReadOnly(element()->readOnly());
-    w->setClickMessage(element()->placeholder().string());
+    w->setPlaceholderText(element()->placeholder().string());
     RenderFormElement::updateFromElement();
 }
 
